@@ -50,7 +50,7 @@ extern const char *pNV_ID;
 static void print_version(void)
 {
     fmtout("");
-    fmtout(pNV_ID);
+    fmtout("%s", pNV_ID);
     fmtoutp(TAB, "The NVIDIA X Configuration Tool.");
     fmtout("");
     fmtoutp(TAB, "This program is used to manipulate X configuration files, "
@@ -87,8 +87,8 @@ static void print_summary(void)
 
 static void print_help_helper(const char *name, const char *description)
 {
-    fmtoutp(TAB, name);
-    fmtoutp(BIGTAB, description);
+    fmtoutp(TAB, "%s", name);
+    fmtoutp(BIGTAB, "%s", description);
     fmtout("");
 }
 
@@ -229,31 +229,6 @@ static void parse_commandline(Options *op, int argc, char *argv[])
                 break;
             }
 
-        case NVAGP_OPTION:
-
-            /* mark as disabled, so we can remove the option later */
-            
-            if (disable) {
-                op->nvagp = -2;
-                break;
-            }
-
-            if      (strcasecmp(strval, "none")    == 0) op->nvagp = 0;
-            else if (strcasecmp(strval, "nvagp")   == 0) op->nvagp = 1;
-            else if (strcasecmp(strval, "agpgart") == 0) op->nvagp = 2;
-            else if (strcasecmp(strval, "any")     == 0) op->nvagp = 3;
-            else if ((strval[0] == '0') && (strval[1] == '\0')) op->nvagp = 0;
-            else if ((strval[0] == '1') && (strval[1] == '\0')) op->nvagp = 1;
-            else if ((strval[0] == '2') && (strval[1] == '\0')) op->nvagp = 2;
-            else if ((strval[0] == '3') && (strval[1] == '\0')) op->nvagp = 3;
-            else {
-                fprintf(stderr, "\n");
-                fprintf(stderr, "Invalid nvagp: %s.\n", strval);
-                fprintf(stderr, "\n");
-                goto fail;
-            }
-            break;
-
         case TRANSPARENT_INDEX_OPTION:
 
             /* mark as disabled, so we can remove the option later */
@@ -338,23 +313,6 @@ static void parse_commandline(Options *op, int argc, char *argv[])
             }
             break;
 
-        case TV_OVER_SCAN_OPTION:
-            
-            /* mark as disabled, so we can remove the option later */
-
-            if (disable) {
-                op->tv_over_scan = -2.0;
-                break;
-            }
-
-            if (doubleval >= 0.0 && doubleval <= 1.0) {
-                op->tv_over_scan = doubleval;
-            } else {
-                fprintf(stderr, "Invalid TVOverScan value: %f.\n", doubleval);
-                goto fail;
-            }
-            break;
-
         case COOL_BITS_OPTION:
 
             /* mark as disabled, so we can remove the option later */
@@ -376,7 +334,7 @@ static void parse_commandline(Options *op, int argc, char *argv[])
                 break;
             }
 
-            if (intval < 0 || intval > 11) {
+            if (intval < 0 || intval > 12) {
                 fprintf(stderr, "\n");
                 fprintf(stderr, "Invalid stereo: %d.\n", intval);
                 fprintf(stderr, "\n");
@@ -505,43 +463,6 @@ static void parse_commandline(Options *op, int argc, char *argv[])
             }
             break;
 
-        case ROTATE_OPTION:
-            {
-                const char* valid_values[] = {
-                    "0",
-                    "no",
-                    "off",
-                    "normal",
-                    "left",
-                    "CCW",
-                    "inverted",
-                    "right",
-                    "CW",
-                    NULL
-                };
-                int i;
-
-                /* mark as disabled, so we can remove the option later */
-
-                if (disable) {
-                    op->rotate = NV_DISABLE_STRING_OPTION;
-                    break;
-                }
-
-                for (i = 0; valid_values[i]; i++) {
-                    if (!strcasecmp(strval, valid_values[i]))
-                        break;
-                }
-
-                if (valid_values[i]) {
-                    op->rotate = strval;
-                } else {
-                    fprintf(stderr, "Invalid Rotate option: %s.\n", strval);
-                    goto fail;
-                }
-            }
-            break;
-
         case PRESERVE_DRIVER_NAME_OPTION: op->preserve_driver = TRUE; break;
         
         case DISABLE_SCF_OPTION: op->disable_scf = TRUE; break;
@@ -718,7 +639,6 @@ static Options *load_default_options(void)
     op = (Options *) nvalloc(sizeof(Options));
     if (!op) return NULL;
     
-    op->nvagp = -1;
     op->transparent_index = -1;
     op->stereo = -1;
     op->cool_bits = -1;
